==> skrooge-0.2.5.tar.gz: skrooge-0.2.5/skgbasegui/skgsortfilterproxymodel.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSORTFILTERPROXYMODEL_H
#define SKGSORTFILTERPROXYMODEL_H
/** @file
 * This file is a proxy model with better filter mechanism.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include <kglobal.h>

#include <QSortFilterProxyModel>

/**
 * This class is a proxy model with better filter mechanism
 */
class KDE_EXPORT SKGSortFilterProxyModel : public QSortFilterProxyModel
{
public:
        /**
         * Contructor
         * @param parent parent widget
         */
        SKGSortFilterProxyModel( QObject * parent = 0 );

        /**
         * Destructor
         */
        virtual ~SKGSortFilterProxyModel();

protected:
        /**
         * To know if a row must be displayed or not
         * @param source_row source row
         * @param source_parent prent
         * @return true of false
         */
        virtual bool filterAcceptsRow ( int source_row, const QModelIndex & source_parent ) const;

};

#endif

==> skrooge-0.5.2.tar.gz: skrooge-0.5.2/skgbasegui/skgsortfilterproxymodel.h <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@miraks.com    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
#ifndef SKGSORTFILTERPROXYMODEL_H
#define SKGSORTFILTERPROXYMODEL_H
/** @file
 * This file is a proxy model with better filter mechanism.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include <kglobal.h>

#include <QSortFilterProxyModel>
#include "skgbasegui_export.h"
/**
 * This class is a proxy model with better filter mechanism
 */
class SKGBASEGUI_EXPORT SKGSortFilterProxyModel : public QSortFilterProxyModel
{
public:
        /**
         * Contructor
         * @param parent parent widget
         */
        SKGSortFilterProxyModel( QObject * parent = 0 );

        /**
         * Destructor
         */
        virtual ~SKGSortFilterProxyModel();

protected:
        /**
         * To know if a row must be displayed or not
         * @param source_row source row
         * @param source_parent prent
         * @return true of false
         */
        virtual bool filterAcceptsRow ( int source_row, const QModelIndex & source_parent ) const;

};

#endif
